# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/context/context_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.context import types_pb2 as t2iapi_dot_context_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%t2iapi/context/context_requests.proto\x12\x0et2iapi.context\x1a\x1at2iapi/context/types.proto\"9\n\x19\x43ontextStateHandleRequest\x12\x1c\n\x14\x63ontext_state_handle\x18\x01 \x01(\t\"L\n\x18SetLocationDetailRequest\x12\x30\n\x08location\x18\x01 \x01(\x0b\x32\x1e.t2iapi.context.LocationDetail\"\x9d\x01\n!SetContextStateAssociationRequest\x12\x19\n\x11\x64\x65scriptor_handle\x18\x01 \x01(\t\x12\x1c\n\x14\x63ontext_state_handle\x18\x02 \x01(\t\x12?\n\x13\x63ontext_association\x18\x03 \x01(\x0e\x32\".t2iapi.context.ContextAssociation\"\x86\x01\n(CreateContextStateWithAssociationRequest\x12\x19\n\x11\x64\x65scriptor_handle\x18\x01 \x01(\t\x12?\n\x13\x63ontext_association\x18\x02 \x01(\x0e\x32\".t2iapi.context.ContextAssociation\"\xab\x01\n5CreateContextStateWithAssociationAndValidatorsRequest\x12\x19\n\x11\x64\x65scriptor_handle\x18\x01 \x01(\t\x12?\n\x13\x63ontext_association\x18\x02 \x01(\x0e\x32\".t2iapi.context.ContextAssociation\x12\x16\n\x0enum_validators\x18\x03 \x01(\t\"\xcb\x01\n6CreateContextStateWithAssocAndSpecificValidatorRequest\x12\x19\n\x11\x64\x65scriptor_handle\x18\x01 \x01(\t\x12?\n\x13\x63ontext_association\x18\x02 \x01(\x0e\x32\".t2iapi.context.ContextAssociation\x12\x35\n\x0evalidator_type\x18\x03 \x01(\x0e\x32\x1d.t2iapi.context.ValidatorType\"L\n\x17\x41ssociatePatientRequest\x12\x31\n\x0cpatient_type\x18\x01 \x01(\x0e\x32\x1b.t2iapi.context.PatientTypeB5\n\"com.draeger.medical.t2iapi.contextB\x0f\x43ontextRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.context.context_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.draeger.medical.t2iapi.contextB\017ContextRequests'
  _CONTEXTSTATEHANDLEREQUEST._serialized_start=85
  _CONTEXTSTATEHANDLEREQUEST._serialized_end=142
  _SETLOCATIONDETAILREQUEST._serialized_start=144
  _SETLOCATIONDETAILREQUEST._serialized_end=220
  _SETCONTEXTSTATEASSOCIATIONREQUEST._serialized_start=223
  _SETCONTEXTSTATEASSOCIATIONREQUEST._serialized_end=380
  _CREATECONTEXTSTATEWITHASSOCIATIONREQUEST._serialized_start=383
  _CREATECONTEXTSTATEWITHASSOCIATIONREQUEST._serialized_end=517
  _CREATECONTEXTSTATEWITHASSOCIATIONANDVALIDATORSREQUEST._serialized_start=520
  _CREATECONTEXTSTATEWITHASSOCIATIONANDVALIDATORSREQUEST._serialized_end=691
  _CREATECONTEXTSTATEWITHASSOCANDSPECIFICVALIDATORREQUEST._serialized_start=694
  _CREATECONTEXTSTATEWITHASSOCANDSPECIFICVALIDATORREQUEST._serialized_end=897
  _ASSOCIATEPATIENTREQUEST._serialized_start=899
  _ASSOCIATEPATIENTREQUEST._serialized_end=975
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/activation_state/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#t2iapi/activation_state/types.proto\x12\x17t2iapi.activation_state*\xdb\x01\n\x13\x43omponentActivation\x12\x1b\n\x17\x43OMPONENT_ACTIVATION_ON\x10\x00\x12\"\n\x1e\x43OMPONENT_ACTIVATION_NOT_READY\x10\x01\x12 \n\x1c\x43OMPONENT_ACTIVATION_STANDBY\x10\x02\x12\x1c\n\x18\x43OMPONENT_ACTIVATION_OFF\x10\x03\x12!\n\x1d\x43OMPONENT_ACTIVATION_SHUTDOWN\x10\x04\x12 \n\x1c\x43OMPONENT_ACTIVATION_FAILURE\x10\x05*^\n\x0f\x41lertActivation\x12\x17\n\x13\x41LERT_ACTIVATION_ON\x10\x00\x12\x18\n\x14\x41LERT_ACTIVATION_OFF\x10\x01\x12\x18\n\x14\x41LERT_ACTIVATION_PSD\x10\x02*\xaa\x01\n\x18\x41lertSignalManifestation\x12\"\n\x1e\x41LERT_SIGNAL_MANIFESTATION_AUD\x10\x00\x12\"\n\x1e\x41LERT_SIGNAL_MANIFESTATION_VIS\x10\x01\x12\"\n\x1e\x41LERT_SIGNAL_MANIFESTATION_TAN\x10\x02\x12\"\n\x1e\x41LERT_SIGNAL_MANIFESTATION_OTH\x10\x03\x42\x43\n+com.draeger.medical.t2iapi.activation_stateB\x14\x41\x63tivationStateTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.activation_state.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.draeger.medical.t2iapi.activation_stateB\024ActivationStateTypes'
  _COMPONENTACTIVATION._serialized_start=65
  _COMPONENTACTIVATION._serialized_end=284
  _ALERTACTIVATION._serialized_start=286
  _ALERTACTIVATION._serialized_end=380
  _ALERTSIGNALMANIFESTATION._serialized_start=383
  _ALERTSIGNALMANIFESTATION._serialized_end=553
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/metric/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi.metric import metric_requests_pb2 as t2iapi_dot_metric_dot_metric__requests__pb2
from t2iapi.metric import metric_responses_pb2 as t2iapi_dot_metric_dot_metric__responses__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bt2iapi/metric/service.proto\x12\rt2iapi.metric\x1a\x1ct2iapi/basic_responses.proto\x1a\x1bt2iapi/basic_requests.proto\x1a#t2iapi/metric/metric_requests.proto\x1a$t2iapi/metric/metric_responses.proto2\xbb\x07\n\rMetricService\x12\x61\n\x18SetMetricQualityValidity\x12..t2iapi.metric.SetMetricQualityValidityRequest\x1a\x15.t2iapi.BasicResponse\x12?\n\nSetNoValue\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x83\x01\n)SetActivationStateAndUserConfirmableValue\x12?.t2iapi.metric.SetActivationStateAndUserConfirmableValueRequest\x1a\x15.t2iapi.BasicResponse\x12\x44\n\x0fSetInvalidValue\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12U\n\x0f\x43\x61librateMetric\x12\x1a.t2iapi.BasicHandleRequest\x1a&.t2iapi.metric.CalibrateMetricResponse\x12m\n\x1eSetMetricValuesWithQualityMode\x12\x34.t2iapi.metric.SetMetricValuesWithQualityModeRequest\x1a\x15.t2iapi.BasicResponse\x12]\n\x16SetMetricValuesInRange\x12,.t2iapi.metric.SetMetricValuesInRangeRequest\x1a\x15.t2iapi.BasicResponse\x12\x63\n\x19\x43hangeOperationModeStatus\x12/.t2iapi.metric.ChangeOperationModeStatusRequest\x1a\x15.t2iapi.BasicResponse\x12O\n\x0fSetMetricStatus\x12%.t2iapi.metric.SetMetricStatusRequest\x1a\x15.t2iapi.BasicResponse\x12_\n\x14IsComputerControlled\x12\x1a.t2iapi.BasicHandleRequest\x1a+.t2iapi.metric.IsComputerControlledResponseB5\n!com.draeger.medical.t2iapi.metricB\x10MetricApiServiceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.metric.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.metricB\020MetricApiService'
  _METRICSERVICE._serialized_start=181
  _METRICSERVICE._serialized_end=1136
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi.metric import metric_requests_pb2 as t2iapi_dot_metric_dot_metric__requests__pb2
from t2iapi.metric import metric_responses_pb2 as t2iapi_dot_metric_dot_metric__responses__pb2


class MetricServiceStub(object):
    """
    Service to handle metric manipulations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetMetricQualityValidity = channel.unary_unary(
                '/t2iapi.metric.MetricService/SetMetricQualityValidity',
                request_serializer=t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricQualityValidityRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetNoValue = channel.unary_unary(
                '/t2iapi.metric.MetricService/SetNoValue',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetActivationStateAndUserConfirmableValue = channel.unary_unary(
                '/t2iapi.metric.MetricService/SetActivationStateAndUserConfirmableValue',
                request_serializer=t2iapi_dot_metric_dot_metric__requests__pb2.SetActivationStateAndUserConfirmableValueRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetInvalidValue = channel.unary_unary(
                '/t2iapi.metric.MetricService/SetInvalidValue',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.CalibrateMetric = channel.unary_unary(
                '/t2iapi.metric.MetricService/CalibrateMetric',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_metric_dot_metric__responses__pb2.CalibrateMetricResponse.FromString,
                )
        self.SetMetricValuesWithQualityMode = channel.unary_unary(
                '/t2iapi.metric.MetricService/SetMetricValuesWithQualityMode',
                request_serializer=t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricValuesWithQualityModeRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetMetricValuesInRange = channel.unary_unary(
                '/t2iapi.metric.MetricService/SetMetricValuesInRange',
                request_serializer=t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricValuesInRangeRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.ChangeOperationModeStatus = channel.unary_unary(
                '/t2iapi.metric.MetricService/ChangeOperationModeStatus',
                request_serializer=t2iapi_dot_metric_dot_metric__requests__pb2.ChangeOperationModeStatusRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetMetricStatus = channel.unary_unary(
                '/t2iapi.metric.MetricService/SetMetricStatus',
                request_serializer=t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricStatusRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.IsComputerControlled = channel.unary_unary(
                '/t2iapi.metric.MetricService/IsComputerControlled',
                request_serializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
                response_deserializer=t2iapi_dot_metric_dot_metric__responses__pb2.IsComputerControlledResponse.FromString,
                )


class MetricServiceServicer(object):
    """
    Service to handle metric manipulations.
    """

    def SetMetricQualityValidity(self, request, context):
        """
        Set the MetricQuality/@Validity of the metric with the given handle to the given validity value.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNoValue(self, request, context):
        """
        Set no metric values for the provided metric handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetActivationStateAndUserConfirmableValue(self, request, context):
        """
        For the metric with the provided handle do the following:
        - set the @ActivationState to the provided value
        - set the pm:MetricValue/@Value resp. @Samples and confirm the value via the device ui
        Ensure that the @ActivationState remains set for as long as the confirmable value is set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetInvalidValue(self, request, context):
        """
        Set the metric value for the provided handle to an invalid value.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CalibrateMetric(self, request, context):
        """
        Calibrate the metric for the provided handle and return the calibration values.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMetricValuesWithQualityMode(self, request, context):
        """
        Provide metric values with a specific MetricQuality/@Mode for the metric with the given handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMetricValuesInRange(self, request, context):
        """
        Set metric values within a given range. If no limit value is defined, random but valid metric values shall be set.
        If a limit is defined, it shall not be violated by metric values.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeOperationModeStatus(self, request, context):
        """
        Change the status of an operation mode.

        An operation mode represents a specific behaviour of a device that can be enabled, paused or disabled,
        typically by the user.
        BICEPS does not provide a model element out of the box that can be used for such a mode, thus the operation mode
        is represented by a pm:EnumStringMetricDescriptor, as described by MPKP draft.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMetricStatus(self, request, context):
        """
        Set the provided measurement, calculation or setting status for the metric of the provided handle. This is not the
        AbstractMetricState/@ActivationState, but the internal state of the device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsComputerControlled(self, request, context):
        """
        Requests if the given metric handle is a computer-controlled metric.

        A computer-controlled metric is a metric with @MetricCategory ∈ { Set, Preset } which is automatically
        adapted by the device under test, e.g. for an FiO2 closed-loop within a device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MetricServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetMetricQualityValidity': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMetricQualityValidity,
                    request_deserializer=t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricQualityValidityRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetNoValue': grpc.unary_unary_rpc_method_handler(
                    servicer.SetNoValue,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetActivationStateAndUserConfirmableValue': grpc.unary_unary_rpc_method_handler(
                    servicer.SetActivationStateAndUserConfirmableValue,
                    request_deserializer=t2iapi_dot_metric_dot_metric__requests__pb2.SetActivationStateAndUserConfirmableValueRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetInvalidValue': grpc.unary_unary_rpc_method_handler(
                    servicer.SetInvalidValue,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'CalibrateMetric': grpc.unary_unary_rpc_method_handler(
                    servicer.CalibrateMetric,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_metric_dot_metric__responses__pb2.CalibrateMetricResponse.SerializeToString,
            ),
            'SetMetricValuesWithQualityMode': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMetricValuesWithQualityMode,
                    request_deserializer=t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricValuesWithQualityModeRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetMetricValuesInRange': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMetricValuesInRange,
                    request_deserializer=t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricValuesInRangeRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'ChangeOperationModeStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeOperationModeStatus,
                    request_deserializer=t2iapi_dot_metric_dot_metric__requests__pb2.ChangeOperationModeStatusRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetMetricStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMetricStatus,
                    request_deserializer=t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricStatusRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'IsComputerControlled': grpc.unary_unary_rpc_method_handler(
                    servicer.IsComputerControlled,
                    request_deserializer=t2iapi_dot_basic__requests__pb2.BasicHandleRequest.FromString,
                    response_serializer=t2iapi_dot_metric_dot_metric__responses__pb2.IsComputerControlledResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            't2iapi.metric.MetricService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MetricService(object):
    """
    Service to handle metric manipulations.
    """

    @staticmethod
    def SetMetricQualityValidity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.metric.MetricService/SetMetricQualityValidity',
            t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricQualityValidityRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetNoValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.metric.MetricService/SetNoValue',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetActivationStateAndUserConfirmableValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.metric.MetricService/SetActivationStateAndUserConfirmableValue',
            t2iapi_dot_metric_dot_metric__requests__pb2.SetActivationStateAndUserConfirmableValueRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetInvalidValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.metric.MetricService/SetInvalidValue',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CalibrateMetric(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.metric.MetricService/CalibrateMetric',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_metric_dot_metric__responses__pb2.CalibrateMetricResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMetricValuesWithQualityMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.metric.MetricService/SetMetricValuesWithQualityMode',
            t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricValuesWithQualityModeRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMetricValuesInRange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.metric.MetricService/SetMetricValuesInRange',
            t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricValuesInRangeRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeOperationModeStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.metric.MetricService/ChangeOperationModeStatus',
            t2iapi_dot_metric_dot_metric__requests__pb2.ChangeOperationModeStatusRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMetricStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.metric.MetricService/SetMetricStatus',
            t2iapi_dot_metric_dot_metric__requests__pb2.SetMetricStatusRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsComputerControlled(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.metric.MetricService/IsComputerControlled',
            t2iapi_dot_basic__requests__pb2.BasicHandleRequest.SerializeToString,
            t2iapi_dot_metric_dot_metric__responses__pb2.IsComputerControlledResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/context/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi.context import context_requests_pb2 as t2iapi_dot_context_dot_context__requests__pb2
from t2iapi.context import context_responses_pb2 as t2iapi_dot_context_dot_context__responses__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ct2iapi/context/service.proto\x12\x0et2iapi.context\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1bt2iapi/basic_requests.proto\x1a\x1ct2iapi/basic_responses.proto\x1a%t2iapi/context/context_requests.proto\x1a&t2iapi/context/context_responses.proto2\xc8\x10\n\x0e\x43ontextService\x12T\n\x11SetLocationDetail\x12(.t2iapi.context.SetLocationDetailRequest\x1a\x15.t2iapi.BasicResponse\x12\x63\n\x1fRemoveAllContextStateValidators\x12).t2iapi.context.ContextStateHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x66\n\x1aSetContextStateAssociation\x12\x31.t2iapi.context.SetContextStateAssociationRequest\x1a\x15.t2iapi.BasicResponse\x12\x98\x01\n!CreateContextStateWithAssociation\x12\x38.t2iapi.context.CreateContextStateWithAssociationRequest\x1a\x39.t2iapi.context.CreateContextStateWithAssociationResponse\x12\xb2\x01\n.CreateContextStateWithAssociationAndValidators\x12\x45.t2iapi.context.CreateContextStateWithAssociationAndValidatorsRequest\x1a\x39.t2iapi.context.CreateContextStateWithAssociationResponse\x12\xc6\x01\n8CreateContextStateWithAssociationAndUniqueIdentification\x12\x38.t2iapi.context.CreateContextStateWithAssociationRequest\x1aP.t2iapi.context.CreateContextStateWithAssociationAndUniqueIdentificationResponse\x12\x88\x01\n5CreateContextStateWithAssocIdentificationAndValidator\x12\x38.t2iapi.context.CreateContextStateWithAssociationRequest\x1a\x15.t2iapi.BasicResponse\x12\x66\n\"RemoveIdentificationOfContextState\x12).t2iapi.context.ContextStateHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x66\n\"ChangeIdentificationOfContextState\x12).t2iapi.context.ContextStateHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\xb4\x01\n/CreateContextStateWithAssocAndSpecificValidator\x12\x46.t2iapi.context.CreateContextStateWithAssocAndSpecificValidatorRequest\x1a\x39.t2iapi.context.CreateContextStateWithAssociationResponse\x12\xb3\x01\n<CreateNeonatalPatientWithAssociationAndMothersIdentification\x12\x38.t2iapi.context.CreateContextStateWithAssociationRequest\x1a\x39.t2iapi.context.CreateContextStateWithAssociationResponse\x12R\n\x10\x41ssociatePatient\x12\'.t2iapi.context.AssociatePatientRequest\x1a\x15.t2iapi.BasicResponse\x12V\n!EnsembleContextIndicateMembership\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x9e\x01\n3EnsembleContextIndicateMembershipWithIdentification\x12\x1a.t2iapi.BasicHandleRequest\x1aK.t2iapi.context.EnsembleContextIndicateMembershipWithIdentificationResponse\x12\x64\n\x18GetSupportedContextTypes\x12\x16.google.protobuf.Empty\x1a\x30.t2iapi.context.GetSupportedContextTypesResponse\x12\x7f\n*AssociatePatientWithAutoGeneratedPatientId\x12\x16.google.protobuf.Empty\x1a\x39.t2iapi.context.CreateContextStateWithAssociationResponseB7\n\"com.draeger.medical.t2iapi.contextB\x11\x43ontextApiServiceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.context.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.draeger.medical.t2iapi.contextB\021ContextApiService'
  _CONTEXTSERVICE._serialized_start=216
  _CONTEXTSERVICE._serialized_end=2336
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/device/device_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.device import types_pb2 as t2iapi_dot_device_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#t2iapi/device/device_requests.proto\x12\rt2iapi.device\x1a\x19t2iapi/device/types.proto\"A\n\x14TriggerReportRequest\x12)\n\x06report\x18\x01 \x01(\x0e\x32\x19.t2iapi.device.ReportType\"N\n\x1dSetDeviceOperatingModeRequest\x12-\n\x04mode\x18\x01 \x01(\x0e\x32\x1f.t2iapi.device.MdsOperatingMode\"&\n\x12SetLanguageRequest\x12\x10\n\x08language\x18\x01 \x01(\t\"7\n\x1b\x43hangeMdibSequenceIdRequest\x12\x18\n\x10\x64\x65scriptive_name\x18\x01 \x01(\t\"a\n%GetRemovableDescriptorsOfClassRequest\x12\x38\n\x10\x64\x65scriptor_class\x18\x01 \x01(\x0e\x32\x1e.t2iapi.device.DescriptorClassB3\n!com.draeger.medical.t2iapi.deviceB\x0e\x44\x65viceRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.device.device_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.deviceB\016DeviceRequests'
  _TRIGGERREPORTREQUEST._serialized_start=81
  _TRIGGERREPORTREQUEST._serialized_end=146
  _SETDEVICEOPERATINGMODEREQUEST._serialized_start=148
  _SETDEVICEOPERATINGMODEREQUEST._serialized_end=226
  _SETLANGUAGEREQUEST._serialized_start=228
  _SETLANGUAGEREQUEST._serialized_end=266
  _CHANGEMDIBSEQUENCEIDREQUEST._serialized_start=268
  _CHANGEMDIBSEQUENCEIDREQUEST._serialized_end=323
  _GETREMOVABLEDESCRIPTORSOFCLASSREQUEST._serialized_start=325
  _GETREMOVABLEDESCRIPTORSOFCLASSREQUEST._serialized_end=422
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from t2iapi.activation_state import activation_state_requests_pb2 as t2iapi_dot_activation__state_dot_activation__state__requests__pb2
from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2


class ActivationStateServiceStub(object):
    """
    Service to handle activation manipulations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetAlertActivation = channel.unary_unary(
                '/t2iapi.activation_state.ActivationStateService/SetAlertActivation',
                request_serializer=t2iapi_dot_activation__state_dot_activation__state__requests__pb2.SetAlertActivationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetComponentActivation = channel.unary_unary(
                '/t2iapi.activation_state.ActivationStateService/SetComponentActivation',
                request_serializer=t2iapi_dot_activation__state_dot_activation__state__requests__pb2.SetComponentActivationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )
        self.SetSystemSignalActivation = channel.unary_unary(
                '/t2iapi.activation_state.ActivationStateService/SetSystemSignalActivation',
                request_serializer=t2iapi_dot_activation__state_dot_activation__state__requests__pb2.SetSystemSignalActivationRequest.SerializeToString,
                response_deserializer=t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
                )


class ActivationStateServiceServicer(object):
    """
    Service to handle activation manipulations.
    """

    def SetAlertActivation(self, request, context):
        """
        Set the ActivationState of the Alert with the given handle to the given AlertActivation value.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetComponentActivation(self, request, context):
        """
        Set the ActivationState of the DeviceComponent or Metric
        with the given handle to the given ComponentActivation value.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSystemSignalActivation(self, request, context):
        """
        Set a SystemSignalActivation for a alert system with the given handle.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ActivationStateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetAlertActivation': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAlertActivation,
                    request_deserializer=t2iapi_dot_activation__state_dot_activation__state__requests__pb2.SetAlertActivationRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetComponentActivation': grpc.unary_unary_rpc_method_handler(
                    servicer.SetComponentActivation,
                    request_deserializer=t2iapi_dot_activation__state_dot_activation__state__requests__pb2.SetComponentActivationRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
            'SetSystemSignalActivation': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSystemSignalActivation,
                    request_deserializer=t2iapi_dot_activation__state_dot_activation__state__requests__pb2.SetSystemSignalActivationRequest.FromString,
                    response_serializer=t2iapi_dot_basic__responses__pb2.BasicResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            't2iapi.activation_state.ActivationStateService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ActivationStateService(object):
    """
    Service to handle activation manipulations.
    """

    @staticmethod
    def SetAlertActivation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.activation_state.ActivationStateService/SetAlertActivation',
            t2iapi_dot_activation__state_dot_activation__state__requests__pb2.SetAlertActivationRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetComponentActivation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.activation_state.ActivationStateService/SetComponentActivation',
            t2iapi_dot_activation__state_dot_activation__state__requests__pb2.SetComponentActivationRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSystemSignalActivation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/t2iapi.activation_state.ActivationStateService/SetSystemSignalActivation',
            t2iapi_dot_activation__state_dot_activation__state__requests__pb2.SetSystemSignalActivationRequest.SerializeToString,
            t2iapi_dot_basic__responses__pb2.BasicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/metric/metric_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.activation_state import types_pb2 as t2iapi_dot_activation__state_dot_types__pb2
from t2iapi.metric import types_pb2 as t2iapi_dot_metric_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#t2iapi/metric/metric_requests.proto\x12\rt2iapi.metric\x1a#t2iapi/activation_state/types.proto\x1a\x19t2iapi/metric/types.proto\"g\n\x1fSetMetricQualityValidityRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x34\n\x08validity\x18\x02 \x01(\x0e\x32\".t2iapi.metric.MeasurementValidity\"d\n%SetMetricValuesWithQualityModeRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12+\n\x04mode\x18\x02 \x01(\x0e\x32\x1d.t2iapi.metric.GenerationMode\"M\n\x1dSetMetricValuesInRangeRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\r\n\x05lower\x18\x02 \x01(\t\x12\r\n\x05upper\x18\x03 \x01(\t\"u\n ChangeOperationModeStatusRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x41\n\x15operation_mode_status\x18\x02 \x01(\x0e\x32\".t2iapi.metric.OperationModeStatus\"U\n\x16SetMetricStatusRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12+\n\x06status\x18\x02 \x01(\x0e\x32\x1b.t2iapi.metric.MetricStatus\"\x84\x01\n0SetActivationStateAndUserConfirmableValueRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12@\n\nactivation\x18\x02 \x01(\x0e\x32,.t2iapi.activation_state.ComponentActivationB3\n!com.draeger.medical.t2iapi.metricB\x0eMetricRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.metric.metric_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.metricB\016MetricRequests'
  _SETMETRICQUALITYVALIDITYREQUEST._serialized_start=118
  _SETMETRICQUALITYVALIDITYREQUEST._serialized_end=221
  _SETMETRICVALUESWITHQUALITYMODEREQUEST._serialized_start=223
  _SETMETRICVALUESWITHQUALITYMODEREQUEST._serialized_end=323
  _SETMETRICVALUESINRANGEREQUEST._serialized_start=325
  _SETMETRICVALUESINRANGEREQUEST._serialized_end=402
  _CHANGEOPERATIONMODESTATUSREQUEST._serialized_start=404
  _CHANGEOPERATIONMODESTATUSREQUEST._serialized_end=521
  _SETMETRICSTATUSREQUEST._serialized_start=523
  _SETMETRICSTATUSREQUEST._serialized_end=608
  _SETACTIVATIONSTATEANDUSERCONFIRMABLEVALUEREQUEST._serialized_start=611
  _SETACTIVATIONSTATEANDUSERCONFIRMABLEVALUEREQUEST._serialized_end=743
# @@protoc_insertion_point(module_scope)



# This Source Code Form is subject to the terms of the MIT License.
#
# Copyright (c) 2022 Draegerwerk AG & Co. KGaA.
# SPDX-License-Identifier: MIT

import os

import setuptools


def read_config_map():
    """
    Reads the config map into a dict.

    @return: a dictionary representing the version config
    """
    with open('../config/versions.txt') as f:
        lines = f.read().splitlines()
        return dict(line.split('=') for line in lines)


def get_build_version():
    """
    Get the package and development release version from the respective environment parameter, if available.
    Otherwise, return '0.0.0.dev0'.
    Following version scheme from https://peps.python.org/pep-0440/#version-scheme

    @return: package version
    """
    package = os.getenv('BASE_PACKAGE_VERSION', default='0.0.0')
    is_release_version = os.getenv("RELEASE_VERSION") == "1"
    if is_release_version:
        return package
    dev_release_segment = f'dev{os.getenv("GITHUB_RUN_NUMBER", default=0)}'
    return f'{package}.{dev_release_segment}'


config_map = read_config_map()

setuptools.setup(
    name='t2iapi',
    version=get_build_version(),
    author='T2I Team',
    author_email='DLCDE-ODDS-T2I@draeger.com',
    description='T2I API for device communication in test scenarios',
    long_description='''
    Contains generated python files created from protobuf files.
    The protobuf files contain the specification of the serialization used to communicate information in test scenarios.
    ''',
    zip_safe=True,
    license='MIT',
    url='https://github.com/Draegerwerk/t2iapi',
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    install_requires=['protobuf==' + config_map['PYTHON_PROTOC_VERSION'],
                      'grpcio==' + config_map['PYTHON_GRPC_VERSION']],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python :: 3 :: Only',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Topic :: Software Development :: Testing',
        'License :: OSI Approved :: MIT License',
    ]
)
